/*
 * WindowsInfo: Windows環境情報クラス
 */

package environment;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;

public final class WindowsInfo extends EnvInfo
{
	//
	// コンストラクタ
	//
	protected WindowsInfo()
	{
	}

	//
	// 再定義メソッド(状態)
	//

	// ルートが複数存在するファイルシステムかを返す
	public boolean isMultiRootFileSystem()
	{
		return true;
	}

	// パス文字列の大文字小文字を無視するかを返す
	public final boolean isPathCharCaseInsensitive()
	{
		return true;
	}

	// スクリプトファイルのデフォルトの拡張子を返す
	public final String getDefaultScriptExt()
	{
		// バージョンを判定してNT系なら"cmd"にすべき
		return "bat";
	}
	
	// Swingが利用可能かを返す
	public boolean isSwingAvailable()
	{
		return true;
	}

	// ウィンドウタイトルに使える文字が基本ラテンだけかを返す
	public boolean isWindowTitleBasicLatinOnly()
	{
		return false;
	}

	// アイコン設定の要不要を返す
	public boolean isIconRequired()
	{
		return true;
	}

	// フレームのサイズ変更が可能かを返す
	public boolean isFrameResizable()
	{
		return true;
	}

	// 全画面表示をするかを返す
	public boolean showMainFrameAsFullScreen()
	{
		return false;
	}

	// メインウィンドウ用のサイズを返す
	public Dimension getDefaultMainFrameSize(
		Component component)	// 参照コンポーネント(入力)
	{
		Dimension size = component.getToolkit().getScreenSize();
		return new Dimension(size.width / 3 * 2, size.height / 3 * 2);
	}

	// メインウィンドウ用のフォントを返す
	public Font getBaseFont(
		Component component)	// 参照コンポーネント(入力)
	{
		// Windowsならメッセージボックス用のフォントを返す
		// それ以外なら16ポイントのフォントを作成する
		Font font = null;

	//	Object objFont = Toolkit.getDefaultToolkit().getDesktopProperty("win.messagebox.font");
		Object objFont = component.getToolkit().getDesktopProperty("win.messagebox.font");
		if (objFont != null && objFont instanceof Font) {
			font = (Font)objFont;
		}
		else {
			// サイズはポイント指定
			font = new Font(super.FONTFACE_DEFAULT, Font.PLAIN, 16);
		}
		return font;
	}

	// メニュー用のフォントを返す
	public Font getMenuFont(
		Component component)	// 参照コンポーネント(入力)
	{
		Object objFont = component.getToolkit().getDesktopProperty("win.menu.font");
		return (objFont != null && objFont instanceof Font ? (Font)objFont : null);
	}

	// マウスの有無を返す
	public boolean hasNoMouse()
	{
		return false;
	}

}
