/*
 * FileUtilities: ファイル関連ユーティリティー 
 */
package io;

import java.io.File;

public final class FileUtilities
{
	//
	// クラスメソッド(公開)
	//
	
	// 名前と拡張子を分離する
	public static String[] separateNameAndExt(
		String strEntryName)	// エントリ名
	{
		if (strEntryName == null) {
			throw new NullPointerException();
		}
		
		String[] entryNames = new String[2];
		int nExtPos = strEntryName.lastIndexOf('.');
		if (0 <= nExtPos) {
			entryNames[0] = strEntryName.substring(0, nExtPos);
			entryNames[1] = strEntryName.substring(nExtPos + 1);
		}
		else {
			entryNames[0] = strEntryName;
			entryNames[1] = "";
		}
		return entryNames;
	}
	
	// 名前と拡張子を結合する
	public static String combineNameAndExt(
		String strName,			// 名前
		String strExtension)	// 拡張子
	{
		if (strName == null) {
			throw new NullPointerException();
		}
		if (strExtension == null) {
			throw new NullPointerException();
		}
		String strFileName = strName;
		if (0 < strExtension.length()) {
			if (strExtension.startsWith(".") == false) {
				strFileName += ".";
			}
			strFileName += strExtension;
		}

		return strFileName;
	}
	public static String combineNameAndExt(
		String[] entryNames)	// エントリ名
	{
		if (entryNames == null) {
			throw new NullPointerException();
		}
		else if (entryNames.length != 2) {
			throw new IllegalArgumentException();
		}
		
		return combineNameAndExt(entryNames[0], entryNames[1]);
	}
	
	// バックアップファイル名を作成する
	public static File makeBackUpFileName(
		File originalFile)	// オリジナルのファイル
	{
		if (originalFile == null) {
			throw new NullPointerException();
		}

		File backUpFile = null;
		
		int nIndex = 1;
		while (backUpFile != null && backUpFile.exists() == false) {
			final String strBackUpName = originalFile.getName()
										 + "."
										 + Integer.toString(nIndex)
										 + "~";
			backUpFile = new File(originalFile.getParentFile(), strBackUpName);
			nIndex++;
		}

		return backUpFile;
	}

	//
	// コンストラクタ
	//
	private FileUtilities()
	{
	}
}
