/*
 * MessageDialog: AWT版メッセージダイアログ
 */
package ui.awt;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Properties;

import ui.WindowUtilities;
import ui.CommonLabelManager;

public final class MessageDialog extends Dialog
	implements ActionListener
{
	//
	// クラスメソッド
	//

	// メッセージダイアログを表示する
	public static void showReportMessage(
		Frame owner,		// 親フレーム
		String strMessage)	// メッセージ文字列
	{
		if (owner == null || strMessage == null) {
			throw new NullPointerException();
		}

		owner.getToolkit().beep();
		new MessageDialog(owner, strMessage, false).show();
	}
	public static void showReportMessage(
		Dialog owner,		// 親ダイアログ
		String strMessage)	// メッセージ文字列
	{
		if (owner == null || strMessage == null) {
			throw new NullPointerException();
		}

		owner.getToolkit().beep();
		new MessageDialog(owner, strMessage, false).show();
	}

	// 確認ダイアログを表示する
	public static boolean showConfirmMessage(
		Frame owner,		// 親フレーム
		String strMessage)	// メッセージ文字列
	{
		if (owner == null || strMessage == null) {
			throw new NullPointerException();
		}

		owner.getToolkit().beep();
		MessageDialog messageDialog = new MessageDialog(owner, strMessage, true); 
		messageDialog.show();
		return messageDialog.getResult();
	}
	public static boolean showConfirmMessage(
		Dialog owner,		// 親ダイアログ
		String strMessage)	// メッセージ文字列
	{
		if (owner == null || strMessage == null) {
			throw new NullPointerException();
		}

		owner.getToolkit().beep();
		MessageDialog messageDialog = new MessageDialog(owner, strMessage, true); 
		messageDialog.show();
		return messageDialog.getResult();
	}

	//
	// 属性
	//
	private final boolean	query;
	private boolean	result;

	private Button okButton;
	private Button cancelButton;

	//
	// 構築子
	//
	private MessageDialog(
		Frame owner,		// 親フレーム
		String strMessage,	// 表示メッセージ
		boolean bQuery)	// 問いあわせフラグ
	{
		// モーダルにするために第二引数にtrueを指定
		super(owner, true);

		query = bQuery;
		init(owner, strMessage, owner.getTitle());
	}

	private MessageDialog(
		Dialog owner,		// 親ダイアログ
		String strMessage,	// 表示メッセージ
		boolean bQuery)	// 問いあわせフラグ
	{
		// Dialogを引数にした構築子にモーダルフラグを渡すためには
		// タイトルも同時に指定しなければならない。ここはなぜか対称性が悪い
		// しかもSL-C860のJ2MEにはDialogを引数にした構築子がない
		super(owner);
		setModal(true);

		query = bQuery;
		init(owner, strMessage, owner.getTitle());
	}

	//
	// 状態
	//

	// 問いあわせた結果を返す
	public boolean getResult()
	{
		return result;
	}
	
	//
	// 実装
	//

	// 初期化する
	private void init(
		Window owner,			// 親ウィンドウ
		String strMessage,		// メッセージ文字列
		String strWindowTitle)	// タイトル文字列
	{
		BorderLayout layout = (BorderLayout)getLayout();
		layout.setHgap(4);
		layout.setVgap(4);

		setTitle(strWindowTitle);
		addWindowListener(new WindowAdapter() {
			public void windowClosing(
				WindowEvent e) {
				close();
			}
		});
		add(new Label(strMessage), BorderLayout.CENTER);

		Container panelControl = new Container();
		panelControl.setLayout(new FlowLayout(FlowLayout.RIGHT));

		Properties label = CommonLabelManager.getProperties();
		okButton = DialogUtilities.createOkButton(this);

		if (query) {
			cancelButton = DialogUtilities.createCancelButton(this);

			Container panelButton = DialogUtilities.createResponseButtonContainer(
									new Button[] { okButton, cancelButton } );

			panelControl.add(panelButton);
		}
		else {
			panelControl.add(okButton);
		}

		add(panelControl, BorderLayout.SOUTH);

		pack();
		setResizable(false);

		// SL-C860のJ2MEにはgetOwner()は存在しない
	//	WindowUtility.MoveWindowToCenter(getOwner(), this);
		WindowUtilities.moveWindowToCenter(owner, this);
		
		result = true;
	}

	// ダイアログを閉じる
	private void close()
	{
		hide();
		dispose();
	}

	//
	// 再定義メソッド(ActionListener)
	//

	// ボタン押し下げ処理を行う
	public void actionPerformed(
		ActionEvent e)	// イベント情報(入力)
	{
		if (query && e.getSource() == cancelButton) {
			result = false;
		}
		else {
			result = true;
		}

		close();
	}
}
