/*
 * ContorollerDefinition: コントローラ定義 
 */

import java.awt.Frame;
import java.awt.event.KeyEvent;
import java.util.Properties;

import ui.ActionDefinition;
import ui.MenuItemDefinition;
import ui.ActionManager;

import view.LabelManager;

public final class ControllerDefinition
{
	//
	// 定数
	//

	public static final int MENU_VIEW	= 2;

	//
	// コンストラクタ
	//
	ControllerDefinition()
	{
	}

	//
	// 操作
	//

	// メニューを構築する
	void buildMenu(
		final MainFrame mainFrame,		// アクションを受けとるメインフレーム
		Frame frame,					// メニューを作成するフレーム
		final ActionManager manager)	// アクションマネージャー
	{
		Properties menuLabelProperties = LabelManager.getMenuLabelProperties();

		// 「登録」メニュー
		final MenuItemDefinition[] registMenuDef = new MenuItemDefinition[] {
			new MenuItemDefinition(
				new ActionDefinition(
					mainFrame.editAction,
					menuLabelProperties.getProperty(LabelManager.MENU_REGIST_EDIT),
					null,
					ActionDefinition.Style.NORMAL),
				KeyEvent.VK_E,
				KeyEvent.VK_E),
			new MenuItemDefinition(
				new ActionDefinition(
					mainFrame.deleteAction,
					menuLabelProperties.getProperty(LabelManager.MENU_REGIST_DELETE),
					null,
					ActionDefinition.Style.NORMAL),
				KeyEvent.VK_D),
			MenuItemDefinition.SEPARATOR,
			new MenuItemDefinition(
				new ActionDefinition(
					mainFrame.createScriptAction,
					menuLabelProperties.getProperty(LabelManager.MENU_REGIST_SCRIPT),
					null,
					ActionDefinition.Style.NORMAL),
				KeyEvent.VK_C),
			MenuItemDefinition.SEPARATOR,
			new MenuItemDefinition(
				new ActionDefinition(
					mainFrame.closeAction,
					menuLabelProperties.getProperty(LabelManager.MENU_REGIST_EXIT),
					null,
					ActionDefinition.Style.NORMAL),
				KeyEvent.VK_C),
		};

		// 「編集」メニュー
		final MenuItemDefinition[] editMenuDef = new MenuItemDefinition[] {
			new MenuItemDefinition(
				new ActionDefinition(
					mainFrame.copyAction,
					menuLabelProperties.getProperty(LabelManager.MENU_EDIT_COPY),
					null,
					ActionDefinition.Style.NORMAL),
				KeyEvent.VK_C,
				KeyEvent.VK_C),
		};

		// 「表示」メニュー
		final MenuItemDefinition[] viewMenuDef = new MenuItemDefinition[] {
			new MenuItemDefinition(
				new ActionDefinition(mainFrame.setStatusBarVisibleAction,
					menuLabelProperties.getProperty(LabelManager.MENU_VIEW_STATUSBAR),
					null,
					ActionDefinition.Style.CHECK),
				KeyEvent.VK_S),
		};

		manager.buildMenu(menuLabelProperties.getProperty(LabelManager.MENU_REGIST), 
							KeyEvent.VK_R,
							registMenuDef,
							frame);
		manager.buildMenu(menuLabelProperties.getProperty(LabelManager.MENU_EDIT), 
							KeyEvent.VK_E,
							editMenuDef,
							frame);
		manager.buildMenu(menuLabelProperties.getProperty(LabelManager.MENU_VIEW), 
							KeyEvent.VK_V,
							viewMenuDef,
							frame);

		mainFrame.setStatusBarVisibleCheckStatus(true);
	}
}
