/*
 * ClassInfoSerializer: 
 */
package view;

import java.io.IOException;
import java.io.StringWriter;
import java.util.Comparator;

import yaml.YamlSerializer;

public final class ClassInfoSerializer
{
	//
	// クラス属性(実装)
	//

	// 文字列比較
	private static final Comparator COMPARATOR = new Comparator() {
		public int compare(Object lhs, Object rhs)
		{
			return lhs.toString().compareTo(rhs.toString());
		}
	};

	//
	// クラスメソッド(公開)
	//

	// クラス情報テキストを返す
	public static String get(
		String strClassName)	// クラス名
	{
		if (strClassName == null) {
			throw new NullPointerException();
		}

		String strClassText;
		try {
			final Class classInfo = Class.forName(strClassName);

			final StringWriter writer = new StringWriter();
			final YamlSerializer serializer = new YamlSerializer(writer, true);

			serializer.writeMapping("Name", classInfo.getName());
			final Class superClass = classInfo.getSuperclass();
			if (superClass != null) {
				serializer.writeMapping("Super Class", superClass);
			}

			writeClassInfo("Interface", classInfo.getInterfaces(), serializer);
			writeClassInfo("Field", classInfo.getDeclaredFields(), serializer);
			writeClassInfo("Constructor", classInfo.getDeclaredConstructors(), serializer);
			writeClassInfo("Method", classInfo.getDeclaredMethods(), serializer);

			strClassText = writer.toString();
		}
		catch (ClassNotFoundException e) {
			strClassText = "(Not found)";
		}
		catch (java.io.IOException e) {
			// 発生しない
			strClassText = ""; 
		}

		return strClassText;
	}

	//
	// クラスメソッド(実装)
	//

	// クラス情報を書きこむ
	private static void writeClassInfo(
		String strKey,				// キー名
		Object[] seq,				// キーに対応する情報の配列
		YamlSerializer serializer)	// 書きこみ対象
		throws IOException
	{
		if (0 < seq.length) {
			java.util.Arrays.sort(seq, COMPARATOR);
			serializer.startWriteMapping(strKey);
			serializer.startChildNode();
			serializer.writeSequences(seq);
			serializer.endChildNode();
		}
	}

	//
	// コンストラクタ
	//
	private ClassInfoSerializer()
	{
	}
}
