/*
 * MainFrameImp: AWT版メインウィンドウ
 * 注記: BridgeパターンのImplementorクラス
 */
package view.awt;

import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.CardLayout;
import java.awt.Choice;
import java.awt.Component;
import java.awt.Container;
import java.awt.Cursor;
import java.awt.FileDialog;
import java.awt.Frame;
import java.awt.GraphicsEnvironment;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Label;
import java.awt.Panel;
import java.awt.SystemColor;
import java.awt.TextArea;
import java.awt.TextComponent;
import java.awt.TextField;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.io.File;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.Set;

import ui.WindowUtilities;
import ui.awt.DirectoryChooser;
import ui.awt.MessageDialog;
import environment.EnvInfo;
import environment.ZaurusJ2MEInfo;

import MainFrame;
import RunProgramInfo;
import view.ImplementOperation;
import view.LabelManager;

public final class MainFrameImp extends Frame
	implements ImplementOperation
{
	//
	// 内部型定義
	//

/*
	// Java実行ファイルフィルタ
	private static class ExecutableFilenameFilter implements FilenameFilter
	{
		//
		// 状態
		//

		// 受け入れ可能ファイルかを返す
		public boolean accept(
			File dir,		// 判定対象ディレクトリ
			String name)	// 判定対象ファイル
		{
			String strFileName = name.toLowerCase();
			return (strFileName.endsWith(".class")
				 || strFileName.endsWith(".jar"));
		}
	}
*/

	//
	// クラスメソッド(公開)
	//
		
	// 「指定」パネルのレイアウトを設定する
	public static void setInputTabPaneLayout(
		Component[] components,	// 設定するコンポーネント
		Container container)	// 設定するコンテナ
	{
		if (components.length != 14) {
			throw new IllegalArgumentException();
		}
		if (container == null) {
			throw new NullPointerException();
		}

		container.setLayout(new GridBagLayout());

		final GridBagConstraints leftColConst = new GridBagConstraints();
	//	leftColConst.anchor = GridBagConstraints.FIRST_LINE_START;
		leftColConst.anchor = GridBagConstraints.NORTHWEST;
		leftColConst.fill = GridBagConstraints.BOTH;
		leftColConst.gridx = 0;
		leftColConst.gridy = 0;
		leftColConst.gridwidth = 2;
		leftColConst.gridheight = 1;
		leftColConst.weightx = 100.0;
		leftColConst.weighty = 0.0;

		// 実行ファイル
		container.add(components[0], leftColConst);

		++leftColConst.gridy;
		leftColConst.gridwidth = 1;
		container.add(components[1], leftColConst);

		final GridBagConstraints rightColConst = new GridBagConstraints();
	//	rightColConst.anchor = GridBagConstraints.FIRST_LINE_START;
		rightColConst.anchor = GridBagConstraints.NORTHWEST;
		rightColConst.fill = GridBagConstraints.HORIZONTAL;
		rightColConst.gridx = 1;
		rightColConst.gridy = leftColConst.gridy;
		rightColConst.gridwidth = 1;
		rightColConst.gridheight = 1;
		rightColConst.weightx = 0.0;

		container.add(components[2], rightColConst);

		// クラスパス
		++leftColConst.gridy;
		leftColConst.gridwidth = 2;
		container.add(components[3], leftColConst);

		++leftColConst.gridy;
		leftColConst.gridwidth = 1;
		leftColConst.gridheight = 2;
		leftColConst.weighty = 100.0;
		container.add(components[4], leftColConst);

		rightColConst.gridy = leftColConst.gridy;
		container.add(components[5], rightColConst);
		++rightColConst.gridy;
		container.add(components[6], rightColConst);

		// 引数		
		leftColConst.gridy = rightColConst.gridy + 1; 
		leftColConst.gridheight = 1;
		leftColConst.gridwidth = 2;
		leftColConst.weighty = 0.0;
		container.add(components[7], leftColConst);

		++leftColConst.gridy;
		leftColConst.gridwidth = 1;
	//	leftColConst.weighty = 50.0;
		leftColConst.weighty = 0.0;
		container.add(components[8], leftColConst);

		// 名前 		
		++leftColConst.gridy;
		leftColConst.gridwidth = 2;
		leftColConst.weighty = 0.0;
		container.add(components[9], leftColConst);

		++leftColConst.gridy;
		leftColConst.gridwidth = 1;
		container.add(components[10], leftColConst);

		rightColConst.gridy = leftColConst.gridy;
		container.add(components[11], rightColConst);

		++rightColConst.gridy;
		container.add(components[12], rightColConst);

		// 実行ボタン
		leftColConst.gridy  = rightColConst.gridy + 1;
		leftColConst.gridwidth = 2;
		leftColConst.weighty = 0.0;
		container.add(components[13], leftColConst);
	}

	// 「JRE」パネルのレイアウトを設定する
	public static void setJreTabPaneLayout(
		Component[] components,	// 設定するコンポーネント
		Container container)	// 設定するコンテナ
	{
		if (components == null) {
			throw new NullPointerException();
		}
		else if (components.length != 4) {
			throw new IllegalArgumentException();
		}
		if (container == null) {
			throw new NullPointerException();
		}
		
		container.setLayout(new GridBagLayout());

		final GridBagConstraints colConst = new GridBagConstraints();
		colConst.anchor = GridBagConstraints.CENTER;
		colConst.fill = GridBagConstraints.BOTH;
		colConst.gridx = 0;
		colConst.gridy = 0;
		colConst.gridwidth = 1;
		colConst.gridheight = 1;
		colConst.weightx = 0.0;
		colConst.weighty = 0.0;

		int nIndex = 0;
		container.add(components[nIndex++], colConst);
		
		colConst.weightx = 1.0;
		++colConst.gridx;
		container.add(components[nIndex++], colConst);

		++colConst.gridx;
		colConst.weightx = 0.0;
		container.add(components[nIndex++], colConst);

		colConst.gridwidth = colConst.gridx + 1;
		colConst.gridx = 0;
		++colConst.gridy;
		colConst.weighty = 1.0;
		container.add(components[nIndex++], colConst);
	}
	
	// 「情報」タブ用テキストを作成する
	public static String getSystemPropertyInfoText()
	{
		final Properties properties = LabelManager.getComponentLabelProperties();
		final StringBuffer sb = new StringBuffer();
		
		sb.append(properties.getProperty(LabelManager.LABEL_INFO_PROPERTIES));
		sb.append(EnvInfo.NEWLINE);
		String[] astrProperties = MainFrame.getSystemPropertiesInfo();
		for (int nIndex = 0; nIndex < astrProperties.length; nIndex++) {
			sb.append(astrProperties[nIndex]);
			sb.append(EnvInfo.NEWLINE);
		}

		sb.append(properties.getProperty(LabelManager.LABEL_INFO_FONT));
		sb.append(EnvInfo.NEWLINE);

		String[] astrFontFmilyName = GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames(); 
		for (int nIndex = 0; nIndex < astrFontFmilyName.length; nIndex++) {
			sb.append(astrFontFmilyName[nIndex]);
			sb.append(EnvInfo.NEWLINE);
		}

		return sb.toString();
	}

	//
	// 属性
	//

	private Choice	choiceView;
	private Container panelPane;

	private java.awt.List listRunInfoName;
	private java.awt.List listClassPath;

	private TextField textName;
	private TextField textFile;
	private TextComponent textArgument;
	private Button buttonRegist;
	private Button buttonUpdate;

	private TextArea textResult;

	private TextArea textClassInfo;

	private TextArea textSysInfo;

	private Label labelStatus;

	//
	// コンストラクタ
	//
	public MainFrameImp()
	{
		super();
	}

	//
	// 実装
	//

	// 「実行」ボタンを作成する
	private Button createExecButton(
		Properties properties)		// 文字列リソースプロパティ
	{
		Button buttonExec = new Button(properties.getProperty(LabelManager.LABEL_BTN_EXEC));
		buttonExec.addActionListener(MainFrame.getInstance().executeAction);

		return buttonExec;
	}
	
	// 「一覧」パネルの内容を初期化する
	private void initSelectPanel(
		Properties properties)		// 文字列リソースプロパティ
	{
		Panel panelInput = new Panel();
		panelInput.setLayout(new BorderLayout());
		listRunInfoName = new java.awt.List(10);

		panelInput.add(listRunInfoName, BorderLayout.CENTER);

		Container panelButton = new Container();
		panelButton.setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		c.fill = GridBagConstraints.BOTH;
		c.weightx = 1.0;
		c.weighty = 1.0;
		c.gridx = 0;
		c.gridy = 0;

		Button buttonUp = new Button(properties.getProperty(LabelManager.LABEL_BTN_UP));
		buttonUp.addActionListener(MainFrame.getInstance().moveUpAction);
		panelButton.add(buttonUp, c);
		
		Button buttonDown = new Button(properties.getProperty(LabelManager.LABEL_BTN_DOWN));
		buttonDown.addActionListener(MainFrame.getInstance().moveDownAction);
		c.gridx++;
		panelButton.add(buttonDown, c);

		c.gridy++;
		c.gridx = 0;
		c.gridwidth = 2;
		panelButton.add(createExecButton(properties), c);

		panelInput.add(panelButton, BorderLayout.SOUTH);
		
		panelPane.add(properties.getProperty(LabelManager.LABEL_PANE_SELECT),
						panelInput);
	}
	
	// 「指定」パネルの内容を初期化する
	private void initInputPanel(
		Properties properties)		// 文字列リソースプロパティ
	{
		// 実行ファイル		
		textFile = new TextField();
		textFile.setColumns(40);
	
		Button buttonRefer = new Button(properties.getProperty(LabelManager.LABEL_BTN_REFER));
		buttonRefer.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				selectExecuteFile();
			}
		});
	
		// クラスパス
		listClassPath = new java.awt.List(2);

		Button refCPBtn = new Button(properties.getProperty(LabelManager.LABEL_BTN_ADD));
		refCPBtn.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				addClassPath();
			}
		});
	
		Button delCPBtn = new Button(properties.getProperty(LabelManager.LABEL_BTN_DELETE));
		delCPBtn.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				removeClassPath();
			}
		});
			
		// 引数		
		if (EnvInfo.getInstance() instanceof ZaurusJ2MEInfo) {
			TextField field = new TextField();
			field.setColumns(textFile.getColumns());
			textArgument = field;
		}
		else {
			TextArea textArea = new TextArea("", 2, textFile.getColumns(), TextArea.SCROLLBARS_VERTICAL_ONLY);
			textArgument = textArea;
		}
	
		// 名前 		
		textName = new TextField();
		textName.setColumns(textFile.getColumns());
	
		buttonRegist = new Button(properties.getProperty(LabelManager.LABEL_BTN_REGIST));
		buttonRegist.addActionListener(MainFrame.getInstance().registAction);
	
		buttonUpdate = new Button(properties.getProperty(LabelManager.LABEL_BTN_UPDATE));
		buttonUpdate.addActionListener(MainFrame.getInstance().updateAction);
	
		final Component[] components = new Component[] {
			new Label(properties.getProperty(LabelManager.LABEL_FILE)),
			textFile,
			buttonRefer,
			new Label(properties.getProperty(LabelManager.LABEL_CP)),
			listClassPath,
			refCPBtn,
			delCPBtn,
			new Label(properties.getProperty(LabelManager.LABEL_ARG)),
			textArgument,
			new Label(properties.getProperty(LabelManager.LABEL_NAME)),
			textName,
			buttonRegist,
			buttonUpdate,
			createExecButton(properties),
		};
	
		final Panel panelInput = new Panel();
		setInputTabPaneLayout(components, panelInput);
		panelPane.add(properties.getProperty(LabelManager.LABEL_PANE_INPUT), panelInput);
	}

	// 「結果」パネルの内容を初期化する
	private void initResultPanel(
		Properties properties)		// 文字列リソースプロパティ
	{
		final Panel panelResult = new Panel();
		panelResult.setLayout(new GridLayout(1, 1));
		textResult = new TextArea(null, 0, 0, TextArea.SCROLLBARS_VERTICAL_ONLY);
		textResult.setEditable(false);
		panelResult.add(textResult);
		panelPane.add(properties.getProperty(LabelManager.LABEL_PANE_RESULT), panelResult);
	}
	
	// 「JRE」パネルの内容を初期化する
	private void initJrePanel(
		Properties properties)		// 文字列リソースプロパティ
	{
		final Panel panelJre = new Panel();

		final TextField field = new TextField();
		final Button button = new Button(properties.getProperty(LabelManager.LABEL_BTN_SHOW));
		button.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent event) {
				final Cursor saveCursor = getCursor();
				setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
				textClassInfo.setText(view.ClassInfoSerializer.get(field.getText()));
				setCursor(saveCursor);
			}
		});
		textClassInfo = new TextArea(null, 0, 0, TextArea.SCROLLBARS_BOTH);
		textClassInfo.setEditable(false);

		final Component[] components = new Component[] {
			new Label(properties.getProperty(LabelManager.LABEL_CLASS)),
			field,
			button,
			textClassInfo,
		};
		setJreTabPaneLayout(components, panelJre);
		panelPane.add(properties.getProperty(LabelManager.LABEL_PANE_JRE), panelJre);
	}
	
	// 「情報」パネルの内容を初期化する
	private void initSysInfoPanel(
		Properties properties)		// 文字列リソースプロパティ
	{
		final Panel panelSysInfo = new Panel();
		panelSysInfo.setLayout(new GridLayout(1, 1));
		textSysInfo = new TextArea(null, 0, 0, TextArea.SCROLLBARS_VERTICAL_ONLY);
		textSysInfo.setEditable(false);
		panelSysInfo.add(textSysInfo);
		panelPane.add(properties.getProperty(LabelManager.LABEL_PANE_INFO), panelSysInfo);
	}
	
	// ファイル参照処理を行う
	private void selectExecuteFile()
	{
		FileDialog fileDialog = new FileDialog(this,
												MainFrame.getFrameTitle(MainFrame.RESKEY_WIN_SELECTFILE),
												FileDialog.LOAD);
		if (0 < textFile.getText().length()) { 
			fileDialog.setFile(textFile.getText());
		}
	//	fileDialog.setFilenameFilter(new ExecutableFilenameFilter());

		fileDialog.show();
		if (fileDialog.getFile() != null) {
			textFile.setText(fileDialog.getDirectory() + fileDialog.getFile());
		}
	}

	// 表示するカードを選択する
	private void selectCard()
	{
		((CardLayout)panelPane.getLayout()).show(panelPane, choiceView.getSelectedItem());
		if (getCurrentViewState() == MainFrame.ViewState.INFO
		&& textSysInfo.getText().length() == 0) {
			final Cursor saveCursor = getCursor();
			setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));

			textSysInfo.setVisible(false);
			
			textSysInfo.setText(getSystemPropertyInfoText());
			textSysInfo.setCaretPosition(0);
			textSysInfo.setVisible(true);

			setCursor(saveCursor);
		}
	}
	
	// ディレクトリ選択ダイアログを表示する
	private String showDirectorySelectDialog(
		String strWindowTitle,	// ウィンドウタイトル文字列
		String strInitialPath)	// 初期パス
	{
		if (strWindowTitle == null) {
			throw new NullPointerException();
		}

/* FileDialog使用版
		FileDialog fileDialog = new FileDialog(this,
												strWindowTitle,
												FileDialog.LOAD);
		if (strInitialPath != null && 0 < strInitialPath.length()) { 
			fileDialog.setFile(strInitialPath);
		}
	//	fileDialog.setFilenameFilter(new ExecutableFilenameFilter());

		fileDialog.show();
		StringBuffer sb = new StringBuffer();
		if (fileDialog.getDirectory() != null) {
			sb.append(fileDialog.getDirectory());
		}
		if (fileDialog.getFile() != null) {
			sb.append(fileDialog.getFile());
		}
		
		return sb.toString();
*/
		DirectoryChooser chooser = new DirectoryChooser(this, strWindowTitle, true, strInitialPath);
		WindowUtilities.moveWindowToCenter(this, chooser);
		chooser.show();
		return (chooser.getResult() ? chooser.getPath() : "");
	}

	// クラスパス設定処理を行う
	private void addClassPath()
	{
		String strSelectedPath = showDirectorySelectDialog(MainFrame.getFrameTitle(MainFrame.RESKEY_WIN_ADDTCLASSPATH),
															EnvInfo.getInstance().getUserHomeDir());
		if (0 < strSelectedPath.length()) {
			boolean bContains = false;
			String[] astrItems = listClassPath.getItems();
			for (int nIndex = 0; nIndex < astrItems.length; nIndex++) {
				if (astrItems[nIndex].compareToIgnoreCase(strSelectedPath) == 0) {
					bContains = true;
					break;
				}
			}
			if (bContains == false) {
				listClassPath.add(strSelectedPath);

				int nLastIndex = listClassPath.getItemCount() - 1;
				listClassPath.select(nLastIndex);
				listClassPath.makeVisible(nLastIndex);
			}
		}
	}

	// クラスパス削除処理を行う
	private void removeClassPath()
	{
		final int nSelectedIndex = listClassPath.getSelectedIndex(); 
		if (0 <= nSelectedIndex) {
			listClassPath.remove(nSelectedIndex);
		}
		else {
			getToolkit().beep();
		}
	}

	//
	// 再定義メソッド(ImplementOperation)
	//

	// コンポーネントを初期化する
	public void initComponent()	// コンポーネント用リソース
	{
		// レイアウトマネージャを設定する
		setLayout(new BorderLayout(4, 4));

		// ウィンドウ背景色を設定する
		setBackground(SystemColor.menu);

		final Properties properties = LabelManager.getComponentLabelProperties();

		choiceView = new Choice();
		choiceView.add(properties.getProperty(LabelManager.LABEL_PANE_SELECT));
		choiceView.add(properties.getProperty(LabelManager.LABEL_PANE_INPUT));
		choiceView.add(properties.getProperty(LabelManager.LABEL_PANE_RESULT));
		choiceView.add(properties.getProperty(LabelManager.LABEL_PANE_JRE));
		choiceView.add(properties.getProperty(LabelManager.LABEL_PANE_INFO));
		choiceView.addItemListener(new ItemListener() {
			public void itemStateChanged(ItemEvent e) {
				selectCard();
			} 
		});

		add(choiceView, BorderLayout.NORTH);

		panelPane = new Container();
		CardLayout layout = new CardLayout();
		panelPane.setLayout(layout);
		add(panelPane, BorderLayout.CENTER);

		initSelectPanel(properties);

		initInputPanel(properties);

		initResultPanel(properties);

		initJrePanel(properties);

		initSysInfoPanel(properties);

		layout.last(panelPane);

		labelStatus = new Label(properties.getProperty(LabelManager.LABEL_STATUS_READY));
		add(labelStatus, BorderLayout.SOUTH);

		selectCard();
	}

	// メッセージダイアログを表示する
	public void showMessage(
		String strMessage)	// メッセージ文字列(入力)
	{
		MessageDialog.showReportMessage(this, strMessage);
	}

	//
	// 再定義メソッド(ImplementOperation)
	//

	// 確認メッセージを表示する
	public boolean showConfirmMessage(
		String strMessage)	// メッセージ文字列
	{
		return MessageDialog.showConfirmMessage(this, strMessage); 
	}

	// 現在の表示状態を返す 
	public MainFrame.ViewState getCurrentViewState()
	{
		MainFrame.ViewState state;
		switch (choiceView.getSelectedIndex()) {
			case 0:
				state = MainFrame.ViewState.LIST; 
				break;
			case 1:
				state = MainFrame.ViewState.EDIT; 
				break;
			case 2:
				state = MainFrame.ViewState.RESULT; 
				break;
			case 3:
				state = MainFrame.ViewState.JRE; 
				break;
			case 4:
				state = MainFrame.ViewState.INFO; 
				break;
			default:
				throw new IllegalArgumentException();
		}
		return state;
	}

	// 編集中の実行情報を返す 
	public RunProgramInfo getEditingRunProgramInfo()
	{
		RunProgramInfo info = null;
		if (0 < textFile.getText().length()) {
			info = new RunProgramInfo(textName.getText(),
										textFile.getText(),
										textArgument.getText().replace('\n', ' '),
										Arrays.asList(listClassPath.getItems())); 
		}
		return info;
	}

	// 編集中の実行情報を返す
	public int getSelectedRunInfoIndex()
	{
		return listRunInfoName.getSelectedIndex();
	}
	
	// クリップボードにコピーするテキストを返す
	public String getTextToCopyToClipboard()
	{
		String strTextToCopy = null;

		TextArea textArea = null;
		final MainFrame.ViewState state = getCurrentViewState();
		if (state == MainFrame.ViewState.RESULT) {
			textArea = textResult;
		}
		else if (state == MainFrame.ViewState.JRE) {
			textArea = textClassInfo;
		}
		else if (state == MainFrame.ViewState.INFO) {
			textArea = textSysInfo;
		}

		if (textArea != null) {
			if (textArea.getSelectionStart() < textArea.getSelectionEnd()) {
				strTextToCopy = textArea.getSelectedText();
			}
			else {
				strTextToCopy = textArea.getText();
			}
		}

		return strTextToCopy;
	}

	// 作成スクリプトのファイルパスを返す
	public String getCreateScriptFilePath(
		String strDefaultPath,	// デフォルトのパス
		String strDefaultName)	// デフォルトのファイル名
	{
		if (strDefaultPath == null) {
			throw new NullPointerException();
		}
		if (strDefaultName == null) {
			throw new NullPointerException();
		}

		FileDialog fileDialog = new FileDialog(this,
												MainFrame.getFrameTitle(MainFrame.RESKEY_WIN_SCRIPTFILEPATH),
												FileDialog.SAVE);

		StringBuffer sb = new StringBuffer();
		if (0 < strDefaultPath.length()) { 
			sb.append(strDefaultPath);
			sb.append(File.separatorChar);
		}
		if (0 < strDefaultName.length()) {
			sb.append(strDefaultName);
		} 

		if (0 < sb.length()) {
			fileDialog.setFile(sb.toString());
		}
	//	fileDialog.setFilenameFilter(new ExecutableFilenameFilter());

		fileDialog.show();

		sb.setLength(0);
		if (fileDialog.getDirectory() != null) {
			sb.append(fileDialog.getDirectory());
		}
		if (fileDialog.getFile() != null) {
			sb.append(fileDialog.getFile());
		}

		return sb.toString();
	}

	// 現在の見た目の名前を返す
	public Map getAdditionalState()
	{
		Map mapState = new HashMap();
		mapState.put(MainFrame.PROPKEY_STATUSBAR, new Boolean(labelStatus.isVisible()).toString());
		return mapState;
	}

	// 追加の状態を設定する
	public void setAdditionalState(
		Map properties)	// 状態プロパティ
	{
		if (properties == null) {
			throw new IllegalArgumentException();
		}

		if (properties.containsKey(MainFrame.PROPKEY_STATUSBAR)) {
			final boolean bVisible = new Boolean((String)properties.get(MainFrame.PROPKEY_STATUSBAR)).booleanValue();
			labelStatus.setVisible(bVisible);
			MainFrame.getInstance().setStatusBarVisibleCheckStatus(bVisible);
		}
	}
	
	// 表示を切り替える
	public void selectView(
		final MainFrame.ViewState viewState)	// 表示状態
	{
		final int nSelectedIndex;
		if (viewState == MainFrame.ViewState.LIST) {
			nSelectedIndex = 0;
		}
		else if (viewState == MainFrame.ViewState.EDIT) {
			nSelectedIndex = 1;
			
		}
		else if (viewState == MainFrame.ViewState.RESULT) {
			nSelectedIndex = 2;
		}
		else {
			throw new IllegalArgumentException();
		}

		if (choiceView.getSelectedIndex() != nSelectedIndex) {
			choiceView.select(nSelectedIndex);
			selectCard();
		}
	}

	// 実行情報の一覧を設定する	
	public void setRunInfoViewList(
		List runInfoList)	// 実行情報の一覧
	{
		if (runInfoList == null) {
			throw new NullPointerException();
		}

		listRunInfoName.setVisible(false);

		// リストをクリアする
		listRunInfoName.removeAll();

		// リストに名前を設定する
		Iterator it = runInfoList.iterator();
		while (it.hasNext()) {
			RunProgramInfo info = (RunProgramInfo)it.next();
			listRunInfoName.add(info.getName());
		}

		listRunInfoName.setVisible(true);
	}

	// 編集実行情報を設定する
	public void setListSelectedIndex(
		int nIndex)	// 選択インデックス
	{
		listRunInfoName.select(nIndex);
	}

	// 編集実行情報を設定する
	public void setEditRunProgramInfo(
		RunProgramInfo runInfo)	// 実行情報
	{
		if (runInfo == null) {
			throw new NullPointerException();
		}

		textName.setText(runInfo.getName());
		textFile.setText(runInfo.getProgram());
		textArgument.setText(runInfo.getArgument()); 

		listClassPath.removeAll(); 
		Set setClassPath = runInfo.getClassPath();
		Iterator it = setClassPath.iterator();
		while (it.hasNext()) {
			listClassPath.add((String)it.next());
		}
	}

	// 結果を設定する
	public void reportResult(
		String strResult,		// 結果文字列
		boolean bDeleteResult)	// 結果削除フラグ
	{
		if (strResult == null) {
			throw new IllegalArgumentException();
		}

		final String strNewLineCode = EnvInfo.NEWLINE;
		if (bDeleteResult) {
			textResult.replaceRange("", 0, textResult.getText().indexOf(strNewLineCode) + strNewLineCode.length());
		}

		textResult.append(strResult + strNewLineCode);
		setStatusText(strResult);
	}

	// ステータスバーにテキストを設定する
	public void setStatusText(
		String strText)	// 設定するテキスト
	{
		labelStatus.setText(strText);
	}

	// ステータスバーの表示状態を設定する
	public boolean setStatusBarVisible(
		boolean bVisible)	// 表示フラグ
	{
		labelStatus.setVisible(bVisible);
		labelStatus.invalidate();
		validate();

		return bVisible;
	}
}
